@@ -1,7 +1,39 @@
-#!/usr/bin/python
-# $Id: $
+# ----------------------------------------------------------------------------
+# pyglet
+# Copyright (c) 2006-2008 Alex Holkner
+# Copyright (c) 2008-2021 pyglet contributors
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+#
+#  * Redistributions of source code must retain the above copyright
+#    notice, this list of conditions and the following disclaimer.
+#  * Redistributions in binary form must reproduce the above copyright
+#    notice, this list of conditions and the following disclaimer in
+#    the documentation and/or other materials provided with the
+#    distribution.
+#  * Neither the name of pyglet nor the names of its
+#    contributors may be used to endorse or promote products
+#    derived from this software without specific prior written
+#    permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
+# ----------------------------------------------------------------------------
 
-'''Fork a child process and inform it of mode changes to each screen.  The
+"""Fork a child process and inform it of mode changes to each screen.  The
 child waits until the parent process dies, and then connects to each X server 
 with a mode change and restores the mode.
 
@@ -11,8 +43,7 @@ the process is terminated uncleanly.
 
 The child process is communicated to via a pipe, and watches for parent
 death with a Linux extension signal handler.
-'''
-from builtins import object
+"""
 
 import ctypes
 import os
@@ -21,7 +52,8 @@ import struct
 import threading
 
 from pyglet.libs.x11 import xlib
-from pyglet.compat import asbytes
+from pyglet.util import asbytes
+
 try:
     from pyglet.libs.x11 import xf86vmode
 except:
@@ -32,6 +64,7 @@ _restore_mode_child_installed = False
 _restorable_screens = set()
 _mode_write_pipe = None
 
+
 # Mode packets tell the child process how to restore a given display and
 # screen.  Only one packet should be sent per display/screen (more would
 # indicate redundancy or incorrect restoration).  Packet format is:
@@ -40,9 +73,10 @@ _mode_write_pipe = None
 #   width
 #   height
 #   rate
-class ModePacket(object):
+class ModePacket:
     format = '256siHHI'
     size = struct.calcsize(format)
+
     def __init__(self, display, screen, width, height, rate):
         self.display = display
         self.screen = screen
@@ -51,13 +85,11 @@ class ModePacket(object):
         self.rate = rate
 
     def encode(self):
-        return struct.pack(self.format, self.display, self.screen,
-                           self.width, self.height, self.rate)
+        return struct.pack(self.format, self.display, self.screen, self.width, self.height, self.rate)
 
     @classmethod
     def decode(cls, data):
-        display, screen, width, height, rate = \
-            struct.unpack(cls.format, data)
+        display, screen, width, height, rate = struct.unpack(cls.format, data)
         return cls(display.strip(asbytes('\0')), screen, width, height, rate)
 
     def __repr__(self):
@@ -68,29 +100,31 @@ class ModePacket(object):
     def set(self):
         display = xlib.XOpenDisplay(self.display)
         modes, n_modes = get_modes_array(display, self.screen)
-        mode = get_matching_mode(modes, n_modes, 
-                                 self.width, self.height, self.rate)
+        mode = get_matching_mode(modes, n_modes, self.width, self.height, self.rate)
         if mode is not None:
             xf86vmode.XF86VidModeSwitchToMode(display, self.screen, mode)
         free_modes_array(modes, n_modes)
         xlib.XCloseDisplay(display)
 
+
 def get_modes_array(display, screen):
     count = ctypes.c_int()
     modes = ctypes.POINTER(ctypes.POINTER(xf86vmode.XF86VidModeModeInfo))()
     xf86vmode.XF86VidModeGetAllModeLines(display, screen, count, modes)
     return modes, count.value
 
+
 def get_matching_mode(modes, n_modes, width, height, rate):
     # Copy modes out of list and free list
     for i in range(n_modes):
         mode = modes.contents[i]
-        if (mode.hdisplay == width and 
-            mode.vdisplay == height and 
-            mode.dotclock == rate):
+        if (mode.hdisplay == width and
+                mode.vdisplay == height and
+                mode.dotclock == rate):
             return mode
     return None
 
+
 def free_modes_array(modes, n_modes):
     for i in range(n_modes):
         mode = modes.contents[i]
@@ -98,6 +132,7 @@ def free_modes_array(modes, n_modes):
             xlib.XFree(mode.private)
     xlib.XFree(modes)
 
+
 def _install_restore_mode_child():
     global _mode_write_pipe
     global _restore_mode_child_installed
@@ -123,8 +158,9 @@ def _install_restore_mode_child():
         # stops reading from the mode packet pipe and restores video modes on
         # all displays/screens it knows about.
         def _sighup(signum, frame):
-            parent_wait_lock.release();
-        parent_wait_lock = threading.Lock();
+            parent_wait_lock.release()
+
+        parent_wait_lock = threading.Lock()
         parent_wait_lock.acquire()
         signal.signal(signal.SIGHUP, _sighup)
 
@@ -141,12 +177,12 @@ def _install_restore_mode_child():
                     packets.append(packet)
                     buffer = buffer[ModePacket.size:]
             except OSError:
-                pass # Interrupted system call
+                pass  # Interrupted system call
 
         for packet in packets:
             packet.set()
         os._exit(0)
-        
+
     else:
         # Parent process.  Clean up pipe then continue running program as
         # normal.  Send mode packets through pipe as additional
@@ -154,6 +190,7 @@ def _install_restore_mode_child():
         os.close(mode_read_pipe)
         _restore_mode_child_installed = True
 
+
 def set_initial_mode(mode):
     _install_restore_mode_child()
 
@@ -168,5 +205,3 @@ def set_initial_mode(mode):
 
     os.write(_mode_write_pipe, packet.encode())
     _restorable_screens.add((display, screen))
-
-
