@@ -1,15 +1,16 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
+# Copyright (c) 2008-2021 pyglet contributors
 # All rights reserved.
-# 
+#
 # Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions 
+# modification, are permitted provided that the following conditions
 # are met:
 #
 #  * Redistributions of source code must retain the above copyright
 #    notice, this list of conditions and the following disclaimer.
-#  * Redistributions in binary form must reproduce the above copyright 
+#  * Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in
 #    the documentation and/or other materials provided with the
 #    distribution.
@@ -32,19 +33,12 @@
 # POSSIBILITY OF SUCH DAMAGE.
 # ----------------------------------------------------------------------------
 
-'''
-'''
-from builtins import object
-
-__docformat__ = 'restructuredtext'
-__version__ = '$Id: lib_glx.py 597 2007-02-03 16:13:07Z Alex.Holkner $'
-
 import ctypes
 from ctypes import *
 
 import pyglet
 from pyglet.gl.lib import missing_function, decorate_function
-from pyglet.compat import asbytes
+from pyglet.util import asbytes
 
 __all__ = ['link_GL', 'link_GLU', 'link_WGL']
 
@@ -56,6 +50,7 @@ wgl_lib = gl_lib
 
 if _debug_trace:
     from pyglet.lib import _TraceLibrary
+
     gl_lib = _TraceLibrary(gl_lib)
     glu_lib = _TraceLibrary(glu_lib)
     wgl_lib = _TraceLibrary(wgl_lib)
@@ -68,16 +63,18 @@ try:
 except AttributeError:
     _have_get_proc_address = False
 
-class_slots = ['name', 'requires', 'suggestions', 'ftype','func']
+class_slots = ['name', 'requires', 'suggestions', 'ftype', 'func']
+
 
 def makeWGLFunction(func):
-    class WGLFunction(object):
+    class WGLFunction:
         __slots__ = class_slots
         __call__ = func
-        
+
     return WGLFunction
 
-class WGLFunctionProxy(object):
+
+class WGLFunctionProxy:
     __slots__ = class_slots
 
     def __init__(self, name, ftype, requires, suggestions):
@@ -102,9 +99,10 @@ class WGLFunctionProxy(object):
                 self.name, self.requires, self.suggestions)
 
         self.__class__ = makeWGLFunction(self.func)
-        
+
         return self.func(*args, **kwargs)
 
+
 def link_GL(name, restype, argtypes, requires=None, suggestions=None):
     try:
         func = getattr(gl_lib, name)
@@ -133,6 +131,7 @@ def link_GL(name, restype, argtypes, requires=None, suggestions=None):
 
         return missing_function(name, requires, suggestions)
 
+
 def link_GLU(name, restype, argtypes, requires=None, suggestions=None):
     try:
         func = getattr(glu_lib, name)
@@ -161,4 +160,5 @@ def link_GLU(name, restype, argtypes, requires=None, suggestions=None):
 
         return missing_function(name, requires, suggestions)
 
-link_WGL = link_GL
\ No newline at end of file
+
+link_WGL = link_GL
