@@ -1,15 +1,16 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
+# Copyright (c) 2008-2021 pyglet contributors
 # All rights reserved.
-# 
+#
 # Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions 
+# modification, are permitted provided that the following conditions
 # are met:
 #
 #  * Redistributions of source code must retain the above copyright
 #    notice, this list of conditions and the following disclaimer.
-#  * Redistributions in binary form must reproduce the above copyright 
+#  * Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in
 #    the documentation and/or other materials provided with the
 #    distribution.
@@ -32,7 +33,7 @@
 # POSSIBILITY OF SUCH DAMAGE.
 # ----------------------------------------------------------------------------
 
-'''Decode HTML into attributed text.
+"""Decode HTML into attributed text.
 
 A subset of HTML 4.01 Transitional is implemented.  The following elements are
 supported fully::
@@ -46,41 +47,41 @@ out-of-stream text.  This means lists display as expected, but behave a little
 oddly if edited.
 
 No CSS styling is supported.
-'''
-from builtins import chr
+"""
 
-__docformat__ = 'restructuredtext'
-__version__ = '$Id: $'
-
-from future.moves.html.parser import HTMLParser
-from future.moves.html import entities
 import re
 
+from html.parser import HTMLParser
+from html import entities
+
 import pyglet
 from pyglet.text.formats import structured
 
+
 def _hex_color(val):
     return [(val >> 16) & 0xff, (val >> 8) & 0xff, val & 0xff, 255]
 
+
 _color_names = {
-    'black':    _hex_color(0x000000),
-    'silver':   _hex_color(0xc0c0c0),
-    'gray':     _hex_color(0x808080),
-    'white':    _hex_color(0xffffff),
-    'maroon':   _hex_color(0x800000),
-    'red':      _hex_color(0xff0000),
-    'purple':   _hex_color(0x800080),
-    'fucsia':   _hex_color(0x008000),
-    'green':    _hex_color(0x00ff00),
-    'lime':     _hex_color(0xffff00),
-    'olive':    _hex_color(0x808000),
-    'yellow':   _hex_color(0xff0000),
-    'navy':     _hex_color(0x000080),
-    'blue':     _hex_color(0x0000ff),
-    'teal':     _hex_color(0x008080),
-    'aqua':     _hex_color(0x00ffff),
+    'black': _hex_color(0x000000),
+    'silver': _hex_color(0xc0c0c0),
+    'gray': _hex_color(0x808080),
+    'white': _hex_color(0xffffff),
+    'maroon': _hex_color(0x800000),
+    'red': _hex_color(0xff0000),
+    'purple': _hex_color(0x800080),
+    'fucsia': _hex_color(0x008000),
+    'green': _hex_color(0x00ff00),
+    'lime': _hex_color(0xffff00),
+    'olive': _hex_color(0x808000),
+    'yellow': _hex_color(0xff0000),
+    'navy': _hex_color(0x000080),
+    'blue': _hex_color(0x0000ff),
+    'teal': _hex_color(0x008080),
+    'aqua': _hex_color(0x00ffff),
 }
 
+
 def _parse_color(value):
     if value.startswith('#'):
         return _hex_color(int(value[1:], 16))
@@ -90,20 +91,20 @@ def _parse_color(value):
         except KeyError:
             raise ValueError()
 
+
 _whitespace_re = re.compile(u'[\u0020\u0009\u000c\u200b\r\n]+', re.DOTALL)
 
 _metadata_elements = ['head', 'title']
 
-_block_elements = ['p', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 
-                   'ul', 'ol', 'dir', 'menu', 
-                   'pre', 'dl', 'div', 'center', 
+_block_elements = ['p', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6',
+                   'ul', 'ol', 'dir', 'menu',
+                   'pre', 'dl', 'div', 'center',
                    'noscript', 'noframes', 'blockquote', 'form',
                    'isindex', 'hr', 'table', 'fieldset', 'address',
-                    # Incorrect, but we treat list items as blocks:
+                   # Incorrect, but we treat list items as blocks:
                    'li', 'dd', 'dt', ]
-                  
 
-_block_containers = ['_top_block', 
+_block_containers = ['_top_block',
                      'body', 'div', 'center', 'object', 'applet',
                      'blockquote', 'ins', 'del', 'dd', 'li', 'form',
                      'fieldset', 'button', 'th', 'td', 'iframe', 'noscript',
@@ -113,8 +114,8 @@ _block_containers = ['_top_block',
 
 
 class HTMLDecoder(HTMLParser, structured.StructuredTextDecoder):
-    '''Decoder for HTML documents.
-    '''
+    """Decoder for HTML documents.
+    """
     #: Default style attributes for unstyled text in the HTML document.
     #:
     #: :type: dict
@@ -122,6 +123,8 @@ class HTMLDecoder(HTMLParser, structured.StructuredTextDecoder):
         'font_name': 'Times New Roman',
         'font_size': 12,
         'margin_bottom': '12pt',
+        'bold': False,
+        'italic': False,
     }
 
     #: Map HTML font sizes to actual font sizes, in points.
@@ -208,7 +211,7 @@ class HTMLDecoder(HTMLParser, structured.StructuredTextDecoder):
             style['font_name'] = 'Courier New'
         elif element == 'u':
             color = self.current_style.get('color')
-            if color is None: 
+            if color is None:
                 color = [0, 0, 0, 255]
             style['underline'] = color
         elif element == 'font':
@@ -352,7 +355,7 @@ class HTMLDecoder(HTMLParser, structured.StructuredTextDecoder):
     def handle_entityref(self, name):
         if name in entities.name2codepoint:
             self.handle_data(chr(entities.name2codepoint[name]))
-    
+
     def handle_charref(self, name):
         name = name.lower()
         try:
